@@ -775,7 +775,7 @@ class VariableOsLocationData(LocationHelper, TableVariable):
     Select installation disk variable
     """
     opt = ["--disk", "-d"]
-    metavalue = 'DISKS'
+    metavalue = 'DISK[[:MP[:FS[:FORMAT]]]]'
     untrusted = True
     source = ["os_location_source",
               "os_location_dest",
@@ -786,10 +786,12 @@ class VariableOsLocationData(LocationHelper, TableVariable):
     check_after = ["os_install_root_type"]
 
     def init(self):
-        self.help = _("DISK bound for installation will be mounted to the "
-                      "DIR directory. If set to 'none', the mount point will "
-                      "not be moved. To create a bind mount point, you have "
-                      "to specify the source directory as DISK")
+        self.help = (_("DISK bound for installation will be mounted to the "
+                      "MP directory. To create a bind mount point, you have "
+                      "to specify the source directory as DISK") + ". " +
+                    _("To change the filesystem, you have to specify it as FS. "
+                      "FORMAT is used for the specifying the need to format "
+                      "partition or not"))
         self.label = _("Layout")
 
     def set(self, value):
