@@ -225,8 +225,8 @@ class VariableClMigrateUserGroups(UserHelper, Variable):
         self.label = _("Groups")
 
     def set(self, value):
-        value = map(lambda x: x \
-            if x and any(x) else self.getDefaultGroups(),
+        value = map(lambda x: (filter(None, x) if x and any(x)
+                               else self.getDefaultGroups()),
                     value)
         return value
 
@@ -241,15 +241,17 @@ class VariableClMigrateUserGroups(UserHelper, Variable):
         User groups
         """
         passwdList = getPasswdUsers()
-        return map(lambda x: (self.getPrimaryGroup(x) + (getUserGroups(x)
-                                                         if x in passwdList else self.getDefaultGroups())),
+        return map(lambda x: (self.getPrimaryGroup(x) +
+                              (getUserGroups(x)
+                               if x in passwdList else
+                               self.getDefaultGroups())),
                    self.Get('cl_migrate_user'))
 
     def choice(self):
         """
         Available groups
         """
-        return getGroups()
+        return [("", _("Default"))] + [(x, x) for x in getGroups()]
 
 
 class VariableClMigrateUserPwd(UserHelper, Variable):
